# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v4alpha/udp_default_writer_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/listener/v4alpha/udp_default_writer_config.proto',
  package='envoy.config.listener.v4alpha',
  syntax='proto3',
  serialized_options=b'\n+io.envoyproxy.envoy.config.listener.v4alphaB\033UdpDefaultWriterConfigProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=envoy/config/listener/v4alpha/udp_default_writer_config.proto\x12\x1d\x65nvoy.config.listener.v4alpha\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"R\n\x17UdpDefaultWriterOptions:7\x9a\xc5\x88\x1e\x32\n0envoy.config.listener.v3.UdpDefaultWriterOptionsBT\n+io.envoyproxy.envoy.config.listener.v4alphaB\x1bUdpDefaultWriterConfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_UDPDEFAULTWRITEROPTIONS = _descriptor.Descriptor(
  name='UdpDefaultWriterOptions',
  full_name='envoy.config.listener.v4alpha.UdpDefaultWriterOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.listener.v3.UdpDefaultWriterOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=244,
)

DESCRIPTOR.message_types_by_name['UdpDefaultWriterOptions'] = _UDPDEFAULTWRITEROPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UdpDefaultWriterOptions = _reflection.GeneratedProtocolMessageType('UdpDefaultWriterOptions', (_message.Message,), {
  'DESCRIPTOR' : _UDPDEFAULTWRITEROPTIONS,
  '__module__' : 'envoy.config.listener.v4alpha.udp_default_writer_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v4alpha.UdpDefaultWriterOptions)
  })
_sym_db.RegisterMessage(UdpDefaultWriterOptions)


DESCRIPTOR._options = None
_UDPDEFAULTWRITEROPTIONS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/sni_cluster/v2/sni_cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/network/sni_cluster/v2/sni_cluster.proto',
  package='envoy.config.filter.network.sni_cluster.v2',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.config.filter.network.sni_cluster.v2B\017SniClusterProtoP\001\362\230\376\217\0051\022/envoy.extensions.filters.network.sni_cluster.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/config/filter/network/sni_cluster/v2/sni_cluster.proto\x12*envoy.config.filter.network.sni_cluster.v2\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x0c\n\nSniClusterB\x8c\x01\n8io.envoyproxy.envoy.config.filter.network.sni_cluster.v2B\x0fSniClusterProtoP\x01\xf2\x98\xfe\x8f\x05\x31\x12/envoy.extensions.filters.network.sni_cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_SNICLUSTER = _descriptor.Descriptor(
  name='SniCluster',
  full_name='envoy.config.filter.network.sni_cluster.v2.SniCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=183,
)

DESCRIPTOR.message_types_by_name['SniCluster'] = _SNICLUSTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SniCluster = _reflection.GeneratedProtocolMessageType('SniCluster', (_message.Message,), {
  'DESCRIPTOR' : _SNICLUSTER,
  '__module__' : 'envoy.config.filter.network.sni_cluster.v2.sni_cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.sni_cluster.v2.SniCluster)
  })
_sym_db.RegisterMessage(SniCluster)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/upstreams/tcp/generic/v3/generic_connection_pool.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/upstreams/tcp/generic/v3/generic_connection_pool.proto',
  package='envoy.extensions.upstreams.tcp.generic.v3',
  syntax='proto3',
  serialized_options=b'\n7io.envoyproxy.envoy.extensions.upstreams.tcp.generic.v3B$GenericConnectionPoolProtoOuterClassP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGenvoy/extensions/upstreams/tcp/generic/v3/generic_connection_pool.proto\x12)envoy.extensions.upstreams.tcp.generic.v3\x1a\x1dudpa/annotations/status.proto\"\x1c\n\x1aGenericConnectionPoolProtoBi\n7io.envoyproxy.envoy.extensions.upstreams.tcp.generic.v3B$GenericConnectionPoolProtoOuterClassP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_GENERICCONNECTIONPOOLPROTO = _descriptor.Descriptor(
  name='GenericConnectionPoolProto',
  full_name='envoy.extensions.upstreams.tcp.generic.v3.GenericConnectionPoolProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=177,
)

DESCRIPTOR.message_types_by_name['GenericConnectionPoolProto'] = _GENERICCONNECTIONPOOLPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenericConnectionPoolProto = _reflection.GeneratedProtocolMessageType('GenericConnectionPoolProto', (_message.Message,), {
  'DESCRIPTOR' : _GENERICCONNECTIONPOOLPROTO,
  '__module__' : 'envoy.extensions.upstreams.tcp.generic.v3.generic_connection_pool_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.tcp.generic.v3.GenericConnectionPoolProto)
  })
_sym_db.RegisterMessage(GenericConnectionPoolProto)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/listener/v3/lds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/listener/v3/lds.proto',
  package='envoy.service.listener.v3',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.service.listener.v3B\010LdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/service/listener/v3/lds.proto\x12\x19\x65nvoy.service.listener.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"(\n\x08LdsDummy:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.api.v2.LdsDummy2\xd4\x03\n\x18ListenerDiscoveryService\x12}\n\x0e\x44\x65ltaListeners\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12t\n\x0fStreamListeners\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x97\x01\n\x0e\x46\x65tchListeners\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"(\x82\xd3\xe4\x93\x02\x19\"\x17/v3/discovery:listeners\x82\xd3\xe4\x93\x02\x03:\x01*\x1a)\x8a\xa4\x96\xf3\x07#\n!envoy.config.listener.v3.ListenerB@\n\'io.envoyproxy.envoy.service.listener.v3B\x08LdsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_LDSDUMMY = _descriptor.Descriptor(
  name='LdsDummy',
  full_name='envoy.service.listener.v3.LdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.api.v2.LdsDummy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=280,
)

DESCRIPTOR.message_types_by_name['LdsDummy'] = _LDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LdsDummy = _reflection.GeneratedProtocolMessageType('LdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _LDSDUMMY,
  '__module__' : 'envoy.service.listener.v3.lds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.listener.v3.LdsDummy)
  })
_sym_db.RegisterMessage(LdsDummy)


DESCRIPTOR._options = None
_LDSDUMMY._options = None

_LISTENERDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ListenerDiscoveryService',
  full_name='envoy.service.listener.v3.ListenerDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007#\n!envoy.config.listener.v3.Listener',
  create_key=_descriptor._internal_create_key,
  serialized_start=283,
  serialized_end=751,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeltaListeners',
    full_name='envoy.service.listener.v3.ListenerDiscoveryService.DeltaListeners',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamListeners',
    full_name='envoy.service.listener.v3.ListenerDiscoveryService.StreamListeners',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchListeners',
    full_name='envoy.service.listener.v3.ListenerDiscoveryService.FetchListeners',
    index=2,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\027/v3/discovery:listeners\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LISTENERDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ListenerDiscoveryService'] = _LISTENERDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/rds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import route_pb2 as envoy_dot_api_dot_v2_dot_route__pb2

from envoy.api.v2.route_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/rds.proto',
  package='envoy.api.v2',
  syntax='proto3',
  serialized_options=b'\n\032io.envoyproxy.envoy.api.v2B\010RdsProtoP\001\210\001\001\362\230\376\217\005\030\022\026envoy.service.route.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x65nvoy/api/v2/rds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x18\x65nvoy/api/v2/route.proto\"\n\n\x08RdsDummy2\xee\x02\n\x15RouteDiscoveryService\x12U\n\x0cStreamRoutes\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12^\n\x0b\x44\x65ltaRoutes\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12u\n\x0b\x46\x65tchRoutes\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"%\x82\xd3\xe4\x93\x02\x16\"\x14/v2/discovery:routes\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\'\x8a\xa4\x96\xf3\x07!\n\x1f\x65nvoy.api.v2.RouteConfiguration2\xab\x01\n\x1bVirtualHostDiscoveryService\x12\x64\n\x11\x44\x65ltaVirtualHosts\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x1a&\x8a\xa4\x96\xf3\x07 \n\x1e\x65nvoy.api.v2.route.VirtualHostBQ\n\x1aio.envoyproxy.envoy.api.v2B\x08RdsProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x18\x12\x16\x65nvoy.service.route.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_route__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_route__pb2.DESCRIPTOR,])




_RDSDUMMY = _descriptor.Descriptor(
  name='RdsDummy',
  full_name='envoy.api.v2.RdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=233,
)

DESCRIPTOR.message_types_by_name['RdsDummy'] = _RDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RdsDummy = _reflection.GeneratedProtocolMessageType('RdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _RDSDUMMY,
  '__module__' : 'envoy.api.v2.rds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.RdsDummy)
  })
_sym_db.RegisterMessage(RdsDummy)


DESCRIPTOR._options = None

_ROUTEDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='RouteDiscoveryService',
  full_name='envoy.api.v2.RouteDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007!\n\037envoy.api.v2.RouteConfiguration',
  create_key=_descriptor._internal_create_key,
  serialized_start=236,
  serialized_end=602,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamRoutes',
    full_name='envoy.api.v2.RouteDiscoveryService.StreamRoutes',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaRoutes',
    full_name='envoy.api.v2.RouteDiscoveryService.DeltaRoutes',
    index=1,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchRoutes',
    full_name='envoy.api.v2.RouteDiscoveryService.FetchRoutes',
    index=2,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\"\024/v2/discovery:routes\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROUTEDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['RouteDiscoveryService'] = _ROUTEDISCOVERYSERVICE


_VIRTUALHOSTDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='VirtualHostDiscoveryService',
  full_name='envoy.api.v2.VirtualHostDiscoveryService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\212\244\226\363\007 \n\036envoy.api.v2.route.VirtualHost',
  create_key=_descriptor._internal_create_key,
  serialized_start=605,
  serialized_end=776,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeltaVirtualHosts',
    full_name='envoy.api.v2.VirtualHostDiscoveryService.DeltaVirtualHosts',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALHOSTDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['VirtualHostDiscoveryService'] = _VIRTUALHOSTDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/alts/v3/alts.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/alts/v3/alts.proto',
  package='envoy.extensions.transport_sockets.alts.v3',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.extensions.transport_sockets.alts.v3B\tAltsProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5envoy/extensions/transport_sockets/alts/v3/alts.proto\x12*envoy.extensions.transport_sockets.alts.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x01\n\x04\x41lts\x12#\n\x12handshaker_service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1d\n\x15peer_service_accounts\x18\x02 \x03(\t:6\x9a\xc5\x88\x1e\x31\n/envoy.config.transport_socket.alts.v2alpha.AltsBO\n8io.envoyproxy.envoy.extensions.transport_sockets.alts.v3B\tAltsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ALTS = _descriptor.Descriptor(
  name='Alts',
  full_name='envoy.extensions.transport_sockets.alts.v3.Alts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='handshaker_service', full_name='envoy.extensions.transport_sockets.alts.v3.Alts.handshaker_service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer_service_accounts', full_name='envoy.extensions.transport_sockets.alts.v3.Alts.peer_service_accounts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.config.transport_socket.alts.v2alpha.Alts',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=323,
)

DESCRIPTOR.message_types_by_name['Alts'] = _ALTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Alts = _reflection.GeneratedProtocolMessageType('Alts', (_message.Message,), {
  'DESCRIPTOR' : _ALTS,
  '__module__' : 'envoy.extensions.transport_sockets.alts.v3.alts_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.alts.v3.Alts)
  })
_sym_db.RegisterMessage(Alts)


DESCRIPTOR._options = None
_ALTS.fields_by_name['handshaker_service']._options = None
_ALTS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/memory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v3/memory.proto',
  package='envoy.admin.v3',
  syntax='proto3',
  serialized_options=b'\n\034io.envoyproxy.envoy.admin.v3B\013MemoryProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x65nvoy/admin/v3/memory.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xbd\x01\n\x06Memory\x12\x11\n\tallocated\x18\x01 \x01(\x04\x12\x11\n\theap_size\x18\x02 \x01(\x04\x12\x19\n\x11pageheap_unmapped\x18\x03 \x01(\x04\x12\x15\n\rpageheap_free\x18\x04 \x01(\x04\x12\x1a\n\x12total_thread_cache\x18\x05 \x01(\x04\x12\x1c\n\x14total_physical_bytes\x18\x06 \x01(\x04:!\x9a\xc5\x88\x1e\x1c\n\x1a\x65nvoy.admin.v2alpha.MemoryB5\n\x1cio.envoyproxy.envoy.admin.v3B\x0bMemoryProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_MEMORY = _descriptor.Descriptor(
  name='Memory',
  full_name='envoy.admin.v3.Memory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allocated', full_name='envoy.admin.v3.Memory.allocated', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heap_size', full_name='envoy.admin.v3.Memory.heap_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pageheap_unmapped', full_name='envoy.admin.v3.Memory.pageheap_unmapped', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pageheap_free', full_name='envoy.admin.v3.Memory.pageheap_free', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_thread_cache', full_name='envoy.admin.v3.Memory.total_thread_cache', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_physical_bytes', full_name='envoy.admin.v3.Memory.total_physical_bytes', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\034\n\032envoy.admin.v2alpha.Memory',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=303,
)

DESCRIPTOR.message_types_by_name['Memory'] = _MEMORY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Memory = _reflection.GeneratedProtocolMessageType('Memory', (_message.Message,), {
  'DESCRIPTOR' : _MEMORY,
  '__module__' : 'envoy.admin.v3.memory_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.Memory)
  })
_sym_db.RegisterMessage(Memory)


DESCRIPTOR._options = None
_MEMORY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/certs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v3/certs.proto',
  package='envoy.admin.v3',
  syntax='proto3',
  serialized_options=b'\n\034io.envoyproxy.envoy.admin.v3B\nCertsProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65nvoy/admin/v3/certs.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"j\n\x0c\x43\x65rtificates\x12\x31\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32\x1b.envoy.admin.v3.Certificate:\'\x9a\xc5\x88\x1e\"\n envoy.admin.v2alpha.Certificates\"\xa2\x01\n\x0b\x43\x65rtificate\x12\x33\n\x07\x63\x61_cert\x18\x01 \x03(\x0b\x32\".envoy.admin.v3.CertificateDetails\x12\x36\n\ncert_chain\x18\x02 \x03(\x0b\x32\".envoy.admin.v3.CertificateDetails:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.admin.v2alpha.Certificate\"\xe2\x03\n\x12\x43\x65rtificateDetails\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12?\n\x11subject_alt_names\x18\x03 \x03(\x0b\x32$.envoy.admin.v3.SubjectAlternateName\x12\x1d\n\x15\x64\x61ys_until_expiration\x18\x04 \x01(\x04\x12.\n\nvalid_from\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x65xpiration_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x0cocsp_details\x18\x07 \x01(\x0b\x32..envoy.admin.v3.CertificateDetails.OcspDetails\x1am\n\x0bOcspDetails\x12.\n\nvalid_from\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:-\x9a\xc5\x88\x1e(\n&envoy.admin.v2alpha.CertificateDetails\"\x83\x01\n\x14SubjectAlternateName\x12\r\n\x03\x64ns\x18\x01 \x01(\tH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x12\x14\n\nip_address\x18\x03 \x01(\tH\x00:/\x9a\xc5\x88\x1e*\n(envoy.admin.v2alpha.SubjectAlternateNameB\x06\n\x04nameB4\n\x1cio.envoyproxy.envoy.admin.v3B\nCertsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_CERTIFICATES = _descriptor.Descriptor(
  name='Certificates',
  full_name='envoy.admin.v3.Certificates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificates', full_name='envoy.admin.v3.Certificates.certificates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.admin.v2alpha.Certificates',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=251,
)


_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='envoy.admin.v3.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ca_cert', full_name='envoy.admin.v3.Certificate.ca_cert', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cert_chain', full_name='envoy.admin.v3.Certificate.cert_chain', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.admin.v2alpha.Certificate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=416,
)


_CERTIFICATEDETAILS_OCSPDETAILS = _descriptor.Descriptor(
  name='OcspDetails',
  full_name='envoy.admin.v3.CertificateDetails.OcspDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid_from', full_name='envoy.admin.v3.CertificateDetails.OcspDetails.valid_from', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='envoy.admin.v3.CertificateDetails.OcspDetails.expiration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=854,
)

_CERTIFICATEDETAILS = _descriptor.Descriptor(
  name='CertificateDetails',
  full_name='envoy.admin.v3.CertificateDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.admin.v3.CertificateDetails.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='envoy.admin.v3.CertificateDetails.serial_number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_alt_names', full_name='envoy.admin.v3.CertificateDetails.subject_alt_names', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='days_until_expiration', full_name='envoy.admin.v3.CertificateDetails.days_until_expiration', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid_from', full_name='envoy.admin.v3.CertificateDetails.valid_from', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_time', full_name='envoy.admin.v3.CertificateDetails.expiration_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocsp_details', full_name='envoy.admin.v3.CertificateDetails.ocsp_details', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CERTIFICATEDETAILS_OCSPDETAILS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.admin.v2alpha.CertificateDetails',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=901,
)


_SUBJECTALTERNATENAME = _descriptor.Descriptor(
  name='SubjectAlternateName',
  full_name='envoy.admin.v3.SubjectAlternateName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns', full_name='envoy.admin.v3.SubjectAlternateName.dns', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='envoy.admin.v3.SubjectAlternateName.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='envoy.admin.v3.SubjectAlternateName.ip_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.admin.v2alpha.SubjectAlternateName',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='name', full_name='envoy.admin.v3.SubjectAlternateName.name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=904,
  serialized_end=1035,
)

_CERTIFICATES.fields_by_name['certificates'].message_type = _CERTIFICATE
_CERTIFICATE.fields_by_name['ca_cert'].message_type = _CERTIFICATEDETAILS
_CERTIFICATE.fields_by_name['cert_chain'].message_type = _CERTIFICATEDETAILS
_CERTIFICATEDETAILS_OCSPDETAILS.fields_by_name['valid_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATEDETAILS_OCSPDETAILS.fields_by_name['expiration'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATEDETAILS_OCSPDETAILS.containing_type = _CERTIFICATEDETAILS
_CERTIFICATEDETAILS.fields_by_name['subject_alt_names'].message_type = _SUBJECTALTERNATENAME
_CERTIFICATEDETAILS.fields_by_name['valid_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATEDETAILS.fields_by_name['expiration_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATEDETAILS.fields_by_name['ocsp_details'].message_type = _CERTIFICATEDETAILS_OCSPDETAILS
_SUBJECTALTERNATENAME.oneofs_by_name['name'].fields.append(
  _SUBJECTALTERNATENAME.fields_by_name['dns'])
_SUBJECTALTERNATENAME.fields_by_name['dns'].containing_oneof = _SUBJECTALTERNATENAME.oneofs_by_name['name']
_SUBJECTALTERNATENAME.oneofs_by_name['name'].fields.append(
  _SUBJECTALTERNATENAME.fields_by_name['uri'])
_SUBJECTALTERNATENAME.fields_by_name['uri'].containing_oneof = _SUBJECTALTERNATENAME.oneofs_by_name['name']
_SUBJECTALTERNATENAME.oneofs_by_name['name'].fields.append(
  _SUBJECTALTERNATENAME.fields_by_name['ip_address'])
_SUBJECTALTERNATENAME.fields_by_name['ip_address'].containing_oneof = _SUBJECTALTERNATENAME.oneofs_by_name['name']
DESCRIPTOR.message_types_by_name['Certificates'] = _CERTIFICATES
DESCRIPTOR.message_types_by_name['Certificate'] = _CERTIFICATE
DESCRIPTOR.message_types_by_name['CertificateDetails'] = _CERTIFICATEDETAILS
DESCRIPTOR.message_types_by_name['SubjectAlternateName'] = _SUBJECTALTERNATENAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Certificates = _reflection.GeneratedProtocolMessageType('Certificates', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATES,
  '__module__' : 'envoy.admin.v3.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.Certificates)
  })
_sym_db.RegisterMessage(Certificates)

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATE,
  '__module__' : 'envoy.admin.v3.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.Certificate)
  })
_sym_db.RegisterMessage(Certificate)

CertificateDetails = _reflection.GeneratedProtocolMessageType('CertificateDetails', (_message.Message,), {

  'OcspDetails' : _reflection.GeneratedProtocolMessageType('OcspDetails', (_message.Message,), {
    'DESCRIPTOR' : _CERTIFICATEDETAILS_OCSPDETAILS,
    '__module__' : 'envoy.admin.v3.certs_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v3.CertificateDetails.OcspDetails)
    })
  ,
  'DESCRIPTOR' : _CERTIFICATEDETAILS,
  '__module__' : 'envoy.admin.v3.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.CertificateDetails)
  })
_sym_db.RegisterMessage(CertificateDetails)
_sym_db.RegisterMessage(CertificateDetails.OcspDetails)

SubjectAlternateName = _reflection.GeneratedProtocolMessageType('SubjectAlternateName', (_message.Message,), {
  'DESCRIPTOR' : _SUBJECTALTERNATENAME,
  '__module__' : 'envoy.admin.v3.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.SubjectAlternateName)
  })
_sym_db.RegisterMessage(SubjectAlternateName)


DESCRIPTOR._options = None
_CERTIFICATES._options = None
_CERTIFICATE._options = None
_CERTIFICATEDETAILS._options = None
_SUBJECTALTERNATENAME._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v3/filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/cluster/v3/filter.proto',
  package='envoy.config.cluster.v3',
  syntax='proto3',
  serialized_options=b'\n%io.envoyproxy.envoy.config.cluster.v3B\013FilterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/config/cluster/v3/filter.proto\x12\x17\x65nvoy.config.cluster.v3\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"o\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12*\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\"\x9a\xc5\x88\x1e\x1d\n\x1b\x65nvoy.api.v2.cluster.FilterB>\n%io.envoyproxy.envoy.config.cluster.v3B\x0b\x46ilterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='envoy.config.cluster.v3.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.cluster.v3.Filter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.cluster.v3.Filter.typed_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\035\n\033envoy.api.v2.cluster.Filter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=294,
)

_FILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'envoy.config.cluster.v3.filter_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v3.Filter)
  })
_sym_db.RegisterMessage(Filter)


DESCRIPTOR._options = None
_FILTER.fields_by_name['name']._options = None
_FILTER._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/thrift/router/v2alpha1/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/thrift/router/v2alpha1/router.proto',
  package='envoy.config.filter.thrift.router.v2alpha1',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.config.filter.thrift.router.v2alpha1B\013RouterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/config/filter/thrift/router/v2alpha1/router.proto\x12*envoy.config.filter.thrift.router.v2alpha1\x1a\x1dudpa/annotations/status.proto\"\x08\n\x06RouterBQ\n8io.envoyproxy.envoy.config.filter.thrift.router.v2alpha1B\x0bRouterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_ROUTER = _descriptor.Descriptor(
  name='Router',
  full_name='envoy.config.filter.thrift.router.v2alpha1.Router',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=142,
)

DESCRIPTOR.message_types_by_name['Router'] = _ROUTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Router = _reflection.GeneratedProtocolMessageType('Router', (_message.Message,), {
  'DESCRIPTOR' : _ROUTER,
  '__module__' : 'envoy.config.filter.thrift.router.v2alpha1.router_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.thrift.router.v2alpha1.Router)
  })
_sym_db.RegisterMessage(Router)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/jwt_authn/v2alpha/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import http_uri_pb2 as envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2
from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/jwt_authn/v2alpha/config.proto',
  package='envoy.config.filter.http.jwt_authn.v2alpha',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.config.filter.http.jwt_authn.v2alphaB\013ConfigProtoP\001\362\230\376\217\005,\022*envoy.extensions.filters.http.jwt_authn.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/config/filter/http/jwt_authn/v2alpha/config.proto\x12*envoy.config.filter.http.jwt_authn.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a envoy/api/v2/core/http_uri.proto\x1a)envoy/api/v2/route/route_components.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8b\x03\n\x0bJwtProvider\x12\x17\n\x06issuer\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x11\n\taudiences\x18\x02 \x03(\t\x12M\n\x0bremote_jwks\x18\x03 \x01(\x0b\x32\x36.envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwksH\x00\x12\x33\n\nlocal_jwks\x18\x04 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceH\x00\x12\x0f\n\x07\x66orward\x18\x05 \x01(\x08\x12K\n\x0c\x66rom_headers\x18\x06 \x03(\x0b\x32\x35.envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader\x12\x13\n\x0b\x66rom_params\x18\x07 \x03(\t\x12\x1e\n\x16\x66orward_payload_header\x18\x08 \x01(\t\x12\x1b\n\x13payload_in_metadata\x18\t \x01(\tB\x1c\n\x15jwks_source_specifier\x12\x03\xf8\x42\x01\"m\n\nRemoteJwks\x12,\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.HttpUri\x12\x31\n\x0e\x63\x61\x63he_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"8\n\tJwtHeader\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x14\n\x0cvalue_prefix\x18\x02 \x01(\t\"A\n\x15ProviderWithAudiences\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t\"\xc0\x03\n\x0eJwtRequirement\x12\x17\n\rprovider_name\x18\x01 \x01(\tH\x00\x12\x63\n\x16provider_and_audiences\x18\x02 \x01(\x0b\x32\x41.envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiencesH\x00\x12X\n\x0crequires_any\x18\x03 \x01(\x0b\x32@.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrListH\x00\x12Y\n\x0crequires_all\x18\x04 \x01(\x0b\x32\x41.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndListH\x00\x12\x39\n\x17\x61llow_missing_or_failed\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rallow_missing\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\x0f\n\rrequires_type\"r\n\x14JwtRequirementOrList\x12Z\n\x0crequirements\x18\x01 \x03(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\"s\n\x15JwtRequirementAndList\x12Z\n\x0crequirements\x18\x01 \x03(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\"\x98\x01\n\x0fRequirementRule\x12\x37\n\x05match\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.route.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12L\n\x08requires\x18\x02 \x01(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement\"\xf2\x01\n\x0f\x46ilterStateRule\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12[\n\x08requires\x18\x03 \x03(\x0b\x32I.envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry\x1ak\n\rRequiresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement:\x02\x38\x01\"\xa3\x03\n\x11JwtAuthentication\x12_\n\tproviders\x18\x01 \x03(\x0b\x32L.envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry\x12J\n\x05rules\x18\x02 \x03(\x0b\x32;.envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule\x12W\n\x12\x66ilter_state_rules\x18\x03 \x01(\x0b\x32;.envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule\x12\x1d\n\x15\x62ypass_cors_preflight\x18\x04 \x01(\x08\x1ai\n\x0eProvidersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider:\x02\x38\x01\x42\x83\x01\n8io.envoyproxy.envoy.config.filter.http.jwt_authn.v2alphaB\x0b\x43onfigProtoP\x01\xf2\x98\xfe\x8f\x05,\x12*envoy.extensions.filters.http.jwt_authn.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_JWTPROVIDER = _descriptor.Descriptor(
  name='JwtProvider',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.issuer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audiences', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.audiences', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_jwks', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.remote_jwks', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_jwks', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.local_jwks', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.forward', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_headers', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.from_headers', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_params', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.from_params', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_payload_header', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.forward_payload_header', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_in_metadata', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.payload_in_metadata', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='jwks_source_specifier', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.jwks_source_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=360,
  serialized_end=755,
)


_REMOTEJWKS = _descriptor.Descriptor(
  name='RemoteJwks',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_uri', full_name='envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks.http_uri', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_duration', full_name='envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks.cache_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=866,
)


_JWTHEADER = _descriptor.Descriptor(
  name='JwtHeader',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_prefix', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader.value_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=924,
)


_PROVIDERWITHAUDIENCES = _descriptor.Descriptor(
  name='ProviderWithAudiences',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audiences', full_name='envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences.audiences', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=926,
  serialized_end=991,
)


_JWTREQUIREMENT = _descriptor.Descriptor(
  name='JwtRequirement',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_and_audiences', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.provider_and_audiences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_any', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.requires_any', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_all', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.requires_all', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_missing_or_failed', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.allow_missing_or_failed', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_missing', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.allow_missing', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='requires_type', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.requires_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=994,
  serialized_end=1442,
)


_JWTREQUIREMENTORLIST = _descriptor.Descriptor(
  name='JwtRequirementOrList',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requirements', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrList.requirements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1444,
  serialized_end=1558,
)


_JWTREQUIREMENTANDLIST = _descriptor.Descriptor(
  name='JwtRequirementAndList',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requirements', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndList.requirements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1560,
  serialized_end=1675,
)


_REQUIREMENTRULE = _descriptor.Descriptor(
  name='RequirementRule',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires', full_name='envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule.requires', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=1830,
)


_FILTERSTATERULE_REQUIRESENTRY = _descriptor.Descriptor(
  name='RequiresEntry',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1968,
  serialized_end=2075,
)

_FILTERSTATERULE = _descriptor.Descriptor(
  name='FilterStateRule',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires', full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.requires', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FILTERSTATERULE_REQUIRESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1833,
  serialized_end=2075,
)


_JWTAUTHENTICATION_PROVIDERSENTRY = _descriptor.Descriptor(
  name='ProvidersEntry',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2392,
  serialized_end=2497,
)

_JWTAUTHENTICATION = _descriptor.Descriptor(
  name='JwtAuthentication',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='providers', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.providers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_state_rules', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.filter_state_rules', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bypass_cors_preflight', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.bypass_cors_preflight', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JWTAUTHENTICATION_PROVIDERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=2497,
)

_JWTPROVIDER.fields_by_name['remote_jwks'].message_type = _REMOTEJWKS
_JWTPROVIDER.fields_by_name['local_jwks'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_JWTPROVIDER.fields_by_name['from_headers'].message_type = _JWTHEADER
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier'].fields.append(
  _JWTPROVIDER.fields_by_name['remote_jwks'])
_JWTPROVIDER.fields_by_name['remote_jwks'].containing_oneof = _JWTPROVIDER.oneofs_by_name['jwks_source_specifier']
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier'].fields.append(
  _JWTPROVIDER.fields_by_name['local_jwks'])
_JWTPROVIDER.fields_by_name['local_jwks'].containing_oneof = _JWTPROVIDER.oneofs_by_name['jwks_source_specifier']
_REMOTEJWKS.fields_by_name['http_uri'].message_type = envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2._HTTPURI
_REMOTEJWKS.fields_by_name['cache_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_JWTREQUIREMENT.fields_by_name['provider_and_audiences'].message_type = _PROVIDERWITHAUDIENCES
_JWTREQUIREMENT.fields_by_name['requires_any'].message_type = _JWTREQUIREMENTORLIST
_JWTREQUIREMENT.fields_by_name['requires_all'].message_type = _JWTREQUIREMENTANDLIST
_JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_JWTREQUIREMENT.fields_by_name['allow_missing'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['provider_name'])
_JWTREQUIREMENT.fields_by_name['provider_name'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['provider_and_audiences'])
_JWTREQUIREMENT.fields_by_name['provider_and_audiences'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['requires_any'])
_JWTREQUIREMENT.fields_by_name['requires_any'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['requires_all'])
_JWTREQUIREMENT.fields_by_name['requires_all'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'])
_JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['allow_missing'])
_JWTREQUIREMENT.fields_by_name['allow_missing'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENTORLIST.fields_by_name['requirements'].message_type = _JWTREQUIREMENT
_JWTREQUIREMENTANDLIST.fields_by_name['requirements'].message_type = _JWTREQUIREMENT
_REQUIREMENTRULE.fields_by_name['match'].message_type = envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2._ROUTEMATCH
_REQUIREMENTRULE.fields_by_name['requires'].message_type = _JWTREQUIREMENT
_FILTERSTATERULE_REQUIRESENTRY.fields_by_name['value'].message_type = _JWTREQUIREMENT
_FILTERSTATERULE_REQUIRESENTRY.containing_type = _FILTERSTATERULE
_FILTERSTATERULE.fields_by_name['requires'].message_type = _FILTERSTATERULE_REQUIRESENTRY
_JWTAUTHENTICATION_PROVIDERSENTRY.fields_by_name['value'].message_type = _JWTPROVIDER
_JWTAUTHENTICATION_PROVIDERSENTRY.containing_type = _JWTAUTHENTICATION
_JWTAUTHENTICATION.fields_by_name['providers'].message_type = _JWTAUTHENTICATION_PROVIDERSENTRY
_JWTAUTHENTICATION.fields_by_name['rules'].message_type = _REQUIREMENTRULE
_JWTAUTHENTICATION.fields_by_name['filter_state_rules'].message_type = _FILTERSTATERULE
DESCRIPTOR.message_types_by_name['JwtProvider'] = _JWTPROVIDER
DESCRIPTOR.message_types_by_name['RemoteJwks'] = _REMOTEJWKS
DESCRIPTOR.message_types_by_name['JwtHeader'] = _JWTHEADER
DESCRIPTOR.message_types_by_name['ProviderWithAudiences'] = _PROVIDERWITHAUDIENCES
DESCRIPTOR.message_types_by_name['JwtRequirement'] = _JWTREQUIREMENT
DESCRIPTOR.message_types_by_name['JwtRequirementOrList'] = _JWTREQUIREMENTORLIST
DESCRIPTOR.message_types_by_name['JwtRequirementAndList'] = _JWTREQUIREMENTANDLIST
DESCRIPTOR.message_types_by_name['RequirementRule'] = _REQUIREMENTRULE
DESCRIPTOR.message_types_by_name['FilterStateRule'] = _FILTERSTATERULE
DESCRIPTOR.message_types_by_name['JwtAuthentication'] = _JWTAUTHENTICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JwtProvider = _reflection.GeneratedProtocolMessageType('JwtProvider', (_message.Message,), {
  'DESCRIPTOR' : _JWTPROVIDER,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider)
  })
_sym_db.RegisterMessage(JwtProvider)

RemoteJwks = _reflection.GeneratedProtocolMessageType('RemoteJwks', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEJWKS,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks)
  })
_sym_db.RegisterMessage(RemoteJwks)

JwtHeader = _reflection.GeneratedProtocolMessageType('JwtHeader', (_message.Message,), {
  'DESCRIPTOR' : _JWTHEADER,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader)
  })
_sym_db.RegisterMessage(JwtHeader)

ProviderWithAudiences = _reflection.GeneratedProtocolMessageType('ProviderWithAudiences', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERWITHAUDIENCES,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences)
  })
_sym_db.RegisterMessage(ProviderWithAudiences)

JwtRequirement = _reflection.GeneratedProtocolMessageType('JwtRequirement', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENT,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement)
  })
_sym_db.RegisterMessage(JwtRequirement)

JwtRequirementOrList = _reflection.GeneratedProtocolMessageType('JwtRequirementOrList', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENTORLIST,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrList)
  })
_sym_db.RegisterMessage(JwtRequirementOrList)

JwtRequirementAndList = _reflection.GeneratedProtocolMessageType('JwtRequirementAndList', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENTANDLIST,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndList)
  })
_sym_db.RegisterMessage(JwtRequirementAndList)

RequirementRule = _reflection.GeneratedProtocolMessageType('RequirementRule', (_message.Message,), {
  'DESCRIPTOR' : _REQUIREMENTRULE,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule)
  })
_sym_db.RegisterMessage(RequirementRule)

FilterStateRule = _reflection.GeneratedProtocolMessageType('FilterStateRule', (_message.Message,), {

  'RequiresEntry' : _reflection.GeneratedProtocolMessageType('RequiresEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILTERSTATERULE_REQUIRESENTRY,
    '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry)
    })
  ,
  'DESCRIPTOR' : _FILTERSTATERULE,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule)
  })
_sym_db.RegisterMessage(FilterStateRule)
_sym_db.RegisterMessage(FilterStateRule.RequiresEntry)

JwtAuthentication = _reflection.GeneratedProtocolMessageType('JwtAuthentication', (_message.Message,), {

  'ProvidersEntry' : _reflection.GeneratedProtocolMessageType('ProvidersEntry', (_message.Message,), {
    'DESCRIPTOR' : _JWTAUTHENTICATION_PROVIDERSENTRY,
    '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry)
    })
  ,
  'DESCRIPTOR' : _JWTAUTHENTICATION,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication)
  })
_sym_db.RegisterMessage(JwtAuthentication)
_sym_db.RegisterMessage(JwtAuthentication.ProvidersEntry)


DESCRIPTOR._options = None
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier']._options = None
_JWTPROVIDER.fields_by_name['issuer']._options = None
_JWTHEADER.fields_by_name['name']._options = None
_JWTREQUIREMENTORLIST.fields_by_name['requirements']._options = None
_JWTREQUIREMENTANDLIST.fields_by_name['requirements']._options = None
_REQUIREMENTRULE.fields_by_name['match']._options = None
_FILTERSTATERULE_REQUIRESENTRY._options = None
_FILTERSTATERULE.fields_by_name['name']._options = None
_JWTAUTHENTICATION_PROVIDERSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/money.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/type/money.proto',
  package='google.type',
  syntax='proto3',
  serialized_options=b'\n\017com.google.typeB\nMoneyProtoP\001Z6google.golang.org/genproto/googleapis/type/money;money\370\001\001\242\002\003GTP',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17google/type/money.proto\x12\x0bgoogle.type\"<\n\x05Money\x12\x15\n\rcurrency_code\x18\x01 \x01(\t\x12\r\n\x05units\x18\x02 \x01(\x03\x12\r\n\x05nanos\x18\x03 \x01(\x05\x42`\n\x0f\x63om.google.typeB\nMoneyProtoP\x01Z6google.golang.org/genproto/googleapis/type/money;money\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3'
)




_MONEY = _descriptor.Descriptor(
  name='Money',
  full_name='google.type.Money',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.type.Money.currency_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='units', full_name='google.type.Money.units', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanos', full_name='google.type.Money.nanos', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=100,
)

DESCRIPTOR.message_types_by_name['Money'] = _MONEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Money = _reflection.GeneratedProtocolMessageType('Money', (_message.Message,), {
  'DESCRIPTOR' : _MONEY,
  '__module__' : 'google.type.money_pb2'
  # @@protoc_insertion_point(class_scope:google.type.Money)
  })
_sym_db.RegisterMessage(Money)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
